nvals = 2:14;
M = 10^5;
sigma = @(x) ones(size(x))./cosh(sin(pi*x));
f = @(x) pi^2*sin(pi*x);
exact = @(x) sinh(sin(pi*x));

xpts = linspace(0,1,M+1)';
xpts = xpts(2:end-1);

l2err = [];
lierr = [];

for N = nvals
    A = getGalMat(sigma, N);
    L = getrhsvector(f, N);
    mu = A \ L;

    approx = evaltrigsum(mu, M);
    err = abs(approx - exact(xpts));
    
    l2err = [l2err; sqrt(sum(err.^2)/M)];
    lierr = [lierr; max(err)];
end 

semilogy(nvals, lierr, 'bo-');
hold on; grid on;
plot(nvals, l2err, 'ro-');
xlim([1, 15]);
xlabel('N');
ylabel('Error');
legend('L^\infty', 'L^2');

P = polyfit(log(nvals), log(log(lierr')),1);
gamma_inf=-real(exp(P(2)));
delta_inf=P(1);

disp(['L-inf convergence exponential with gamma: ' num2str(gamma_inf) ' and delta: ' num2str(delta_inf) ]);
Q = polyfit(log(nvals), log(log(l2err')), 1);
gamma_2=-real(exp(Q(2)));
delta_2=Q(1);
disp(['L-2 convergence exponential with gamma: ' num2str(gamma_2) ' and delta: ' num2str(delta_2) ]);

plot(nvals, exp(-gamma_inf.*nvals.^delta_inf));
hold off;
