function [a,b,c,d] = natcubsplinecoll(M,f)

% Computes the coefficients in the monomial expansion of the spline for
% equispace knots
% INPUT:
% M = number of intervals
% f = FHandle to right-hand side
% OUTPUT:
% column vectors of coefficients in the monomial expansion

h = 1/M;
x = linspace(0,1,M+1);
fval = f(x);
fval = fval(:);
a = (fval(1:end-1)-fval(2:end))/(6*h);
b = [0; -fval(2:end-1)/2];
A11 = diag([-ones(M-1,1);h])+diag(ones(M-1,1),1);
A12 = zeros(M,M);
A12(end,end) = 1;
A21 = zeros(M,M);
A21(end,end-1) = h;
A22 = diag([1;-2*ones(M-2,1);-1])+diag([0;ones(M-2,1)],1)+diag([ones(M-2,1);1],-1);
A = [A11 A12; A21 A22];
RHS = zeros(2*M,1);
RHS(1:M-1)=(fval(2:end-1)+fval(1:end-2))*(-h/2);
RHS(M) = fval(end-1)*h^2/3;
RHS(M+1) = 0;
RHS(M+2:end-1) = -h^2/6*(fval(3:M)+4*fval(2:M-1)+fval(1:M-2));
RHS(end) = h^2/6*(2*fval(M-1)+fval(M));
res = A\RHS;
c = res(1:M);
d = res(M+1:end);

